
From: Martin Waitz <tali@admingilde.org>

Update function parameter description in block/fs code

Signed-off-by: Martin Waitz <tali@admingilde.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/block/ll_rw_blk.c |    3 ++-
 25-akpm/fs/jbd/journal.c          |   21 ++++++++++++++++-----
 25-akpm/fs/jbd/transaction.c      |    3 ++-
 25-akpm/fs/super.c                |    2 +-
 25-akpm/include/linux/jbd.h       |    5 +++++
 25-akpm/kernel/sysctl.c           |    6 ++++++
 6 files changed, 32 insertions(+), 8 deletions(-)

diff -puN drivers/block/ll_rw_blk.c~docbook-update-function-parameter-description-in-block-fs-code drivers/block/ll_rw_blk.c
--- 25/drivers/block/ll_rw_blk.c~docbook-update-function-parameter-description-in-block-fs-code	2005-03-11 12:32:27.000000000 -0800
+++ 25-akpm/drivers/block/ll_rw_blk.c	2005-03-11 12:32:27.000000000 -0800
@@ -816,6 +816,7 @@ fail:
  * blk_queue_init_tags - initialize the queue tag info
  * @q:  the request queue for the device
  * @depth:  the maximum queue depth supported
+ * @tags: the tag to use
  **/
 int blk_queue_init_tags(request_queue_t *q, int depth,
 			struct blk_queue_tag *tags)
@@ -2150,7 +2151,7 @@ EXPORT_SYMBOL(blk_rq_map_user);
 /**
  * blk_rq_unmap_user - unmap a request with user data
  * @rq:		request to be unmapped
- * @ubuf:	user buffer
+ * @bio:	bio for the request
  * @ulen:	length of user buffer
  *
  * Description:
diff -puN fs/jbd/journal.c~docbook-update-function-parameter-description-in-block-fs-code fs/jbd/journal.c
--- 25/fs/jbd/journal.c~docbook-update-function-parameter-description-in-block-fs-code	2005-03-11 12:32:27.000000000 -0800
+++ 25-akpm/fs/jbd/journal.c	2005-03-11 12:32:27.000000000 -0800
@@ -1172,6 +1172,10 @@ void journal_destroy(journal_t *journal)
 
 /**
  *int journal_check_used_features () - Check if features specified are used.
+ * @journal: Journal to check.
+ * @compat: bitmask of compatible features
+ * @ro: bitmask of features that force read-only mount
+ * @incompat: bitmask of incompatible features
  * 
  * Check whether the journal uses all of a given set of
  * features.  Return true (non-zero) if it does. 
@@ -1199,6 +1203,10 @@ int journal_check_used_features (journal
 
 /**
  * int journal_check_available_features() - Check feature set in journalling layer
+ * @journal: Journal to check.
+ * @compat: bitmask of compatible features
+ * @ro: bitmask of features that force read-only mount
+ * @incompat: bitmask of incompatible features
  * 
  * Check whether the journaling code supports the use of
  * all of a given set of features on this journal.  Return true
@@ -1231,6 +1239,10 @@ int journal_check_available_features (jo
 
 /**
  * int journal_set_features () - Mark a given journal feature in the superblock
+ * @journal: Journal to act on.
+ * @compat: bitmask of compatible features
+ * @ro: bitmask of features that force read-only mount
+ * @incompat: bitmask of incompatible features
  *
  * Mark a given journal feature as present on the
  * superblock.  Returns true if the requested features could be set. 
@@ -1263,6 +1275,7 @@ int journal_set_features (journal_t *jou
 
 /**
  * int journal_update_format () - Update on-disk journal structure.
+ * @journal: Journal to act on.
  *
  * Given an initialised but unloaded journal struct, poke about in the
  * on-disk structure to update it to the most recent supported version.
@@ -1563,6 +1576,7 @@ int journal_errno(journal_t *journal)
 
 /** 
  * int journal_clear_err () - clears the journal's error state
+ * @journal: journal to act on.
  *
  * An error must be cleared or Acked to take a FS out of readonly
  * mode.
@@ -1582,6 +1596,7 @@ int journal_clear_err(journal_t *journal
 
 /** 
  * void journal_ack_err() - Ack journal err.
+ * @journal: journal to act on.
  *
  * An error must be cleared or Acked to take a FS out of readonly
  * mode.
@@ -1600,11 +1615,7 @@ int journal_blocks_per_page(struct inode
 }
 
 /*
- * Simple support for retying memory allocations.  Introduced to help to
- * debug different VM deadlock avoidance strategies. 
- */
-/*
- * Simple support for retying memory allocations.  Introduced to help to
+ * Simple support for retrying memory allocations.  Introduced to help to
  * debug different VM deadlock avoidance strategies. 
  */
 void * __jbd_kmalloc (const char *where, size_t size, int flags, int retry)
diff -puN fs/jbd/transaction.c~docbook-update-function-parameter-description-in-block-fs-code fs/jbd/transaction.c
--- 25/fs/jbd/transaction.c~docbook-update-function-parameter-description-in-block-fs-code	2005-03-11 12:32:27.000000000 -0800
+++ 25-akpm/fs/jbd/transaction.c	2005-03-11 12:32:27.000000000 -0800
@@ -733,6 +733,7 @@ out:
  * int journal_get_write_access() - notify intent to modify a buffer for metadata (not data) update.
  * @handle: transaction to add buffer modifications to
  * @bh:     bh to be used for metadata writes
+ * @credits: variable that will receive credits for the buffer
  *
  * Returns an error code or 0 on success.
  *
@@ -1576,7 +1577,7 @@ out:
  * int journal_try_to_free_buffers() - try to free page buffers.
  * @journal: journal for operation
  * @page: to try and free
- * @gfp_mask: 'IO' mode for try_to_free_buffers()
+ * @unused_gfp_mask: unused
  *
  * 
  * For all the buffers on this page,
diff -puN fs/super.c~docbook-update-function-parameter-description-in-block-fs-code fs/super.c
--- 25/fs/super.c~docbook-update-function-parameter-description-in-block-fs-code	2005-03-11 12:32:27.000000000 -0800
+++ 25-akpm/fs/super.c	2005-03-11 12:32:27.000000000 -0800
@@ -143,7 +143,7 @@ int __put_super_and_need_restart(struct 
 
 /**
  *	put_super	-	drop a temporary reference to superblock
- *	@s: superblock in question
+ *	@sb: superblock in question
  *
  *	Drops a temporary reference, frees superblock if there's no
  *	references left.
diff -puN include/linux/jbd.h~docbook-update-function-parameter-description-in-block-fs-code include/linux/jbd.h
--- 25/include/linux/jbd.h~docbook-update-function-parameter-description-in-block-fs-code	2005-03-11 12:32:27.000000000 -0800
+++ 25-akpm/include/linux/jbd.h	2005-03-11 12:32:27.000000000 -0800
@@ -562,6 +562,7 @@ struct transaction_s 
  * @j_sb_buffer: First part of superblock buffer
  * @j_superblock: Second part of superblock buffer
  * @j_format_version: Version of the superblock format
+ * @j_state_lock: Protect the various scalars in the journal
  * @j_barrier_count:  Number of processes waiting to create a barrier lock
  * @j_barrier: The barrier lock itself
  * @j_running_transaction: The current running transaction..
@@ -589,6 +590,7 @@ struct transaction_s 
  * @j_fs_dev: Device which holds the client fs.  For internal journal this will
  *     be equal to j_dev
  * @j_maxlen: Total maximum capacity of the journal region on disk.
+ * @j_list_lock: Protects the buffer lists and internal buffer state.
  * @j_inode: Optional inode where we store the journal.  If present, all journal
  *     block numbers are mapped into this inode via bmap().
  * @j_tail_sequence:  Sequence number of the oldest transaction in the log 
@@ -604,8 +606,11 @@ struct transaction_s 
  * @j_commit_interval: What is the maximum transaction lifetime before we begin
  *  a commit?
  * @j_commit_timer:  The timer used to wakeup the commit thread
+ * @j_revoke_lock: Protect the revoke table
  * @j_revoke: The revoke table - maintains the list of revoked blocks in the
  *     current transaction.
+ * @j_revoke_table: alternate revoke tables for j_revoke
+ * @j_private: An opaque pointer to fs-private information.
  */
 
 struct journal_s
diff -puN kernel/sysctl.c~docbook-update-function-parameter-description-in-block-fs-code kernel/sysctl.c
--- 25/kernel/sysctl.c~docbook-update-function-parameter-description-in-block-fs-code	2005-03-11 12:32:27.000000000 -0800
+++ 25-akpm/kernel/sysctl.c	2005-03-11 12:32:27.000000000 -0800
@@ -1377,6 +1377,7 @@ static ssize_t proc_writesys(struct file
  * @filp: the file structure
  * @buffer: the user buffer
  * @lenp: the size of the user buffer
+ * @ppos: file position
  *
  * Reads/writes a string from/to the user buffer. If the kernel
  * buffer provided is not large enough to hold the string, the
@@ -1593,6 +1594,7 @@ static int do_proc_dointvec(ctl_table *t
  * @filp: the file structure
  * @buffer: the user buffer
  * @lenp: the size of the user buffer
+ * @ppos: file position
  *
  * Reads/writes up to table->maxlen/sizeof(unsigned int) integer
  * values from/to the user buffer, treated as an ASCII string. 
@@ -1697,6 +1699,7 @@ static int do_proc_dointvec_minmax_conv(
  * @filp: the file structure
  * @buffer: the user buffer
  * @lenp: the size of the user buffer
+ * @ppos: file position
  *
  * Reads/writes up to table->maxlen/sizeof(unsigned int) integer
  * values from/to the user buffer, treated as an ASCII string.
@@ -1829,6 +1832,7 @@ static int do_proc_doulongvec_minmax(ctl
  * @filp: the file structure
  * @buffer: the user buffer
  * @lenp: the size of the user buffer
+ * @ppos: file position
  *
  * Reads/writes up to table->maxlen/sizeof(unsigned long) unsigned long
  * values from/to the user buffer, treated as an ASCII string.
@@ -1851,6 +1855,7 @@ int proc_doulongvec_minmax(ctl_table *ta
  * @filp: the file structure
  * @buffer: the user buffer
  * @lenp: the size of the user buffer
+ * @ppos: file position
  *
  * Reads/writes up to table->maxlen/sizeof(unsigned long) unsigned long
  * values from/to the user buffer, treated as an ASCII string. The values
@@ -1941,6 +1946,7 @@ static int do_proc_dointvec_ms_jiffies_c
  * @filp: the file structure
  * @buffer: the user buffer
  * @lenp: the size of the user buffer
+ * @ppos: file position
  *
  * Reads/writes up to table->maxlen/sizeof(unsigned int) integer
  * values from/to the user buffer, treated as an ASCII string. 
_
